linux/appimage: recursively remove ELF debug symbols

This reduces the AppImage's AppDir from 100,5 MiB to 90,3 MiB.
This commit is contained in:
guihkx authored and DevilXD committed 2025-07-26 23:40:01 +02:00
1 parent 42e7e88f30
commit 7116cbc759
1 file changed
+3
+3
View File
@@ -30,6 +30,9 @@ script:
# Generate byte-code files and package them for a slightly faster app startup. # Generate byte-code files and package them for a slightly faster app startup.
- python3 -m compileall "$TARGET_APPDIR/usr/src/"*.py - python3 -m compileall "$TARGET_APPDIR/usr/src/"*.py
# Recursively remove ELF debug symbols, trimming roughly 10 MB off the AppDir.
- find "$TARGET_APPDIR" -type f -print0 | xargs -0 file | grep -F 'not stripped' | cut -f1 -d':' | sort -V | xargs -r strip -s -v
AppDir: AppDir:
app_info: app_info:
id: io.github.devilxd.twitchdropsminer id: io.github.devilxd.twitchdropsminer